@@ -6,6 +6,10 @@ arkhe::bootstrap
 
 # REEXPORT FROM KHROMA
 
+#' @importFrom khroma color
+#' @export
+khroma::color
+
 #' @importFrom khroma palette_color_continuous
 #' @export
 khroma::palette_color_continuous
